@@ -126,6 +126,17 @@ function parse_test(file) {
                     croak(node);
                 }
                 var name = node.left.name;
+                assert.ok([
+                    "beautify",
+                    "expression",
+                    "mangle",
+                    "options",
+                    "rename",
+                ].indexOf(name) >= 0, tmpl("Unsupported setting {name} [{line},{col}]", {
+                    name: name,
+                    line: node.start.line,
+                    col: node.start.col,
+                }));
                 test[name] = evaluate(node.right);
                 return true;
             }
@@ -271,7 +282,9 @@ function test_case(test) {
         expect = test.expect_exact;
     }
     var input = to_toplevel(test.input, test.mangle, test.expression);
-    var input_code = make_code(input, {}, test.expression);
+    var input_code = make_code(input, {
+        keep_quoted_props: true,
+    }, test.expression);
     var input_formatted = make_code(test.input, {
         annotations: true,
         beautify: true,
@@ -307,8 +320,9 @@ function test_case(test) {
             warnings_emitted.push(text);
         }, /"INFO: /.test(expected_warnings));
     }
+    var quoted_props;
     if (test.mangle && test.mangle.properties && test.mangle.properties.keep_quoted) {
-        var quoted_props = test.mangle.properties.reserved;
+        quoted_props = test.mangle.properties.reserved;
         if (!Array.isArray(quoted_props)) quoted_props = [];
         test.mangle.properties.reserved = quoted_props;
         U.reserve_quoted_keys(input, quoted_props);
@@ -323,6 +337,7 @@ function test_case(test) {
     if (test.mangle) {
         output.compute_char_frequency(test.mangle);
         output.mangle_names(test.mangle);
+        if (quoted_props) U.reserve_quoted_keys(input, quoted_props);
         if (test.mangle.properties) U.mangle_properties(output, test.mangle.properties);
     }
     var output_code = make_code(output, output_options, test.expression);
@@ -459,6 +474,7 @@ function to_toplevel(input, mangle_options, expression) {
     var tokens = [];
     input.walk(new U.TreeWalker(function(node) {
         if (U.push_uniq(tokens, node.start)) node.start.line -= offset;
+        if (U.push_uniq(tokens, node.end)) node.end.line -= offset;
     }));
     var toplevel;
     if (!expression) {
