@@ -599,6 +599,7 @@ drop_extends: {
         inline: true,
         passes: 2,
         pure_getters: "strict",
+        reduce_funcs: true,
         reduce_vars: true,
         sequences: true,
         side_effects: true,
@@ -921,6 +922,7 @@ single_use_3: {
 
 single_use_4: {
     options = {
+        reduce_funcs: true,
         reduce_vars: true,
         toplevel: true,
         unused: true,
@@ -1503,6 +1505,218 @@ keep_instanceof_3: {
     node_version: ">=4"
 }
 
+keep_field_reference_1: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        function f() {}
+        class A {
+            p = f;
+        }
+        console.log(new A().p === new A().p ? "PASS" : "FAIL");
+    }
+    expect: {
+        "use strict";
+        function f() {}
+        class A {
+            p = f;
+        }
+        console.log(new A().p === new A().p ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=12"
+}
+
+keep_field_reference_2: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        function f() {}
+        var A = class {
+            p = f;
+        };
+        console.log(new A().p === new A().p ? "PASS" : "FAIL");
+    }
+    expect: {
+        "use strict";
+        function f() {}
+        var A = class {
+            p = f;
+        };
+        console.log(new A().p === new A().p ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=12"
+}
+
+keep_field_reference_3: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        class A {}
+        class B {
+            p = A;
+        }
+        console.log(new B().p === new B().p ? "PASS" : "FAIL");
+    }
+    expect: {
+        "use strict";
+        class A {}
+        class B {
+            p = A;
+        }
+        console.log(new B().p === new B().p ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=12"
+}
+
+keep_field_reference_4: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        var A = class {};
+        var B = class {
+            p = A;
+        };
+        console.log(new B().p === new B().p ? "PASS" : "FAIL");
+    }
+    expect: {
+        "use strict";
+        var A = class {};
+        var B = class {
+            p = A;
+        };
+        console.log(new B().p === new B().p ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=12"
+}
+
+keep_static_field_reference_1: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        function f() {}
+        class A {
+            static P = f;
+        }
+        console.log(A.P === A.P ? "PASS" : "FAIL");
+    }
+    expect: {
+        "use strict";
+        class A {
+            static P = function() {};
+        }
+        console.log(A.P === A.P ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=12"
+}
+
+keep_static_field_reference_2: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        function f() {}
+        var A = class {
+            static P = f;
+        };
+        console.log(A.P === A.P ? "PASS" : "FAIL");
+    }
+    expect: {
+        "use strict";
+        var A = class {
+            static P = function() {};
+        };
+        console.log(A.P === A.P ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=12"
+}
+
+keep_static_field_reference_3: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        class A {}
+        class B {
+            static P = A;
+        }
+        console.log(B.P === B.P ? "PASS" : "FAIL");
+    }
+    expect: {
+        "use strict";
+        class B {
+            static P = class {};
+        }
+        console.log(B.P === B.P ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=12"
+}
+
+keep_static_field_reference_4: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        var A = class {};
+        var B = class {
+            static P = A;
+        };
+        console.log(B.P === B.P ? "PASS" : "FAIL");
+    }
+    expect: {
+        "use strict";
+        var B = class {
+            static P = class {};
+        };
+        console.log(B.P === B.P ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=12"
+}
+
 issue_805_1: {
     options = {
         inline: true,
@@ -2164,6 +2378,7 @@ issue_4829_2: {
 mangle_properties: {
     mangle = {
         properties: {
+            domprops: true,
             keep_quoted: true,
         },
     }
@@ -2200,6 +2415,14 @@ mangle_properties: {
         console.log(A.s, new A().e);
     }
     expect_stdout: "PASS 42"
+    expect_warnings: [
+        "INFO: Preserving reserved property q",
+        "INFO: Mapping property #P to #t",
+        "INFO: Mapping property Q to s",
+        "INFO: Mapping property #p to #i",
+        "INFO: Mapping property r to e",
+        "INFO: Preserving reserved property log",
+    ]
     node_version: ">=14.6"
 }
 
@@ -2304,6 +2527,7 @@ issue_4962_1: {
     options = {
         ie: true,
         inline: true,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -2335,6 +2559,7 @@ issue_4962_1_strict: {
     options = {
         ie: true,
         inline: true,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -2362,6 +2587,7 @@ issue_4962_1_strict_direct: {
     options = {
         ie: true,
         inline: true,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -2393,6 +2619,7 @@ issue_4962_2: {
     options = {
         ie: true,
         inline: true,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -2424,6 +2651,7 @@ issue_4962_2_strict: {
     options = {
         ie: true,
         inline: true,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -2452,6 +2680,7 @@ issue_4962_2_strict_direct: {
     options = {
         ie: true,
         inline: true,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -2486,6 +2715,7 @@ issue_4962_2_strict_direct_inline: {
         ie: true,
         inline: true,
         passes: 2,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -2869,6 +3099,7 @@ issue_5053_4: {
 issue_5082_1: {
     options = {
         inline: true,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -2901,6 +3132,7 @@ issue_5082_1: {
 issue_5082_1_strict: {
     options = {
         inline: true,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -2934,6 +3166,7 @@ issue_5082_2: {
     options = {
         inline: true,
         passes: 2,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -2967,6 +3200,7 @@ issue_5082_2_static: {
     options = {
         inline: true,
         passes: 2,
+        reduce_funcs: true,
         reduce_vars: true,
         unused: true,
     }
@@ -3578,3 +3812,92 @@ issue_5531_3: {
     expect_stdout: "foo"
     node_version: ">=16"
 }
+
+issue_5662: {
+    options = {
+        inline: true,
+        reduce_vars: true,
+    }
+    input: {
+        console.log(new (function() {
+            var g = function(a) {
+                return a;
+            };
+            return class {
+                h(b) {
+                    return g(b);
+                }
+            };
+        }())().h("PASS"));
+    }
+    expect: {
+        console.log(new (function() {
+            var g = function(a) {
+                return a;
+            };
+            return class {
+                h(b) {
+                    return g(b);
+                }
+            };
+        }())().h("PASS"));
+    }
+    expect_stdout: "PASS"
+    node_version: ">=6"
+}
+
+issue_5682_class_key: {
+    mangle = {
+        properties: true,
+    }
+    input: {
+        "use strict";
+        function f(a) {
+            return "foo" in a;
+        }
+        class A {
+            foo() {}
+        }
+        console.log(f(new A()) ? "PASS" : "FAIL");
+    }
+    expect: {
+        "use strict";
+        function f(o) {
+            return "o" in o;
+        }
+        class A {
+            o() {}
+        }
+        console.log(f(new A()) ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
+issue_5682_class_key_computed: {
+    mangle = {
+        properties: true,
+    }
+    input: {
+        "use strict";
+        function f(a) {
+            return "foo" in a;
+        }
+        class A {
+            ["foo"]() {}
+        }
+        console.log(f(new A()) ? "PASS" : "FAIL");
+    }
+    expect: {
+        "use strict";
+        function f(o) {
+            return "o" in o;
+        }
+        class A {
+            ["o"]() {}
+        }
+        console.log(f(new A()) ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
