@@ -278,6 +278,36 @@ merge_tail_2: {
     ]
 }
 
+merge_tail_3: {
+    options = {
+        conditionals: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        (function(a, b) {
+            if (b = a.shift())
+                console.log(b);
+            else {
+                if (b = a.shift())
+                    while (console.log("foo"));
+                console.log(b);
+            }
+        })([ false, "bar" ]);
+    }
+    expect: {
+        (function(a, b) {
+            if (!(b = a.shift()) && (b = a.shift()))
+                while (console.log("foo"));
+            console.log(b);
+        })([ false, "bar" ]);
+    }
+    expect_stdout: [
+        "foo",
+        "bar",
+    ]
+}
+
 merge_tail_sequence_1: {
     options = {
         conditionals: true,
@@ -368,6 +398,39 @@ merge_tail_sequence_2: {
     ]
 }
 
+merge_tail_sequence_3: {
+    options = {
+        conditionals: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        (function(a, b) {
+            if (b = a.shift())
+                console.log("foo"),
+                console.log(b);
+            else {
+                if (b = a.shift())
+                    while (console.log("bar"));
+                console.log(b);
+            }
+        })([ false, "baz" ]);
+    }
+    expect: {
+        (function(a, b) {
+            if (b = a.shift())
+                console.log("foo");
+            else if (b = a.shift())
+                while (console.log("bar"));
+            console.log(b);
+        })([ false, "baz" ]);
+    }
+    expect_stdout: [
+        "bar",
+        "baz",
+    ]
+}
+
 cond_1: {
     options = {
         conditionals: true,
@@ -1176,6 +1239,52 @@ trivial_boolean_ternary_expressions : {
     }
 }
 
+extendscript_1: {
+    beautify = {
+        extendscript: true,
+    }
+    input: {
+        var alert = console.log;
+        function f(a, b) {
+            return a ? b ? "foo" : "bar" : "baz";
+        }
+        alert(f());
+        alert(f(42));
+        alert(f(null, true));
+        alert(f([], {}));
+    }
+    expect_exact: 'var alert=console.log;function f(a,b){return a?(b?"foo":"bar"):"baz"}alert(f());alert(f(42));alert(f(null,true));alert(f([],{}));'
+    expect_stdout: [
+        "baz",
+        "bar",
+        "baz",
+        "foo",
+    ]
+}
+
+extendscript_2: {
+    beautify = {
+        extendscript: true,
+    }
+    input: {
+        var alert = console.log;
+        function f(a, b) {
+            return a ? "foo" : b ? "bar" : "baz";
+        }
+        alert(f());
+        alert(f(42));
+        alert(f(null, true));
+        alert(f([], {}));
+    }
+    expect_exact: 'var alert=console.log;function f(a,b){return a?"foo":(b?"bar":"baz")}alert(f());alert(f(42));alert(f(null,true));alert(f([],{}));'
+    expect_stdout: [
+        "baz",
+        "foo",
+        "bar",
+        "foo",
+    ]
+}
+
 issue_1154: {
     options = {
         booleans: true,
@@ -2832,3 +2941,130 @@ issue_5546_3: {
     }
     expect_stdout: "PASS"
 }
+
+issue_5666_1: {
+    options = {
+        conditionals: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        var a;
+        (function() {
+            var b = a;
+            a ? a = b : (b++, a = b);
+        })();
+        console.log(a);
+    }
+    expect: {
+        var a;
+        (function() {
+            var b = a;
+            a = (a ? 0 : b++, b);
+        })();
+        console.log(a);
+    }
+    expect_stdout: "NaN"
+}
+
+issue_5666_2: {
+    options = {
+        conditionals: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        var a = "foo";
+        (function() {
+            var b = a;
+            a ? (b++, a = b) : a = b;
+        })();
+        console.log(a);
+    }
+    expect: {
+        var a = "foo";
+        (function() {
+            var b = a;
+            a = (a ? b++ : 0, b);
+        })();
+        console.log(a);
+    }
+    expect_stdout: "NaN"
+}
+
+issue_5673_1: {
+    options = {
+        conditionals: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        var a = "PASS", b = null;
+        console.log(function(c) {
+            return c || (b ? c : (c = a) && c);
+        }());
+    }
+    expect: {
+        var a = "PASS", b = null;
+        console.log(function(c) {
+            return c || (b || (c = a)) && c;
+        }());
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5673_2: {
+    options = {
+        conditionals: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        var a = "PASS";
+        console.log(function(b) {
+            return (b = a) ? b : (b = a) && b;
+        }());
+    }
+    expect: {
+        var a = "PASS";
+        console.log(function(b) {
+            return a || (b = a) && b;
+        }());
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5694: {
+    options = {
+        conditionals: true,
+    }
+    input: {
+        FORCE_EXEC = "async()=>{}";
+        var a = "foo";
+        // Node.js v0.12~6 (vm): foo
+        console.log((NaN = a) ? NaN : 42);
+    }
+    expect: {
+        FORCE_EXEC = "async()=>{}";
+        var a = "foo";
+        console.log((NaN = a) ? NaN : 42);
+    }
+    expect_stdout: "NaN"
+}
+
+issue_5712: {
+    options = {
+        booleans: true,
+        conditionals: true,
+        evaluate: true,
+    }
+    input: {
+        var a = 0;
+        a || (++a).toString() && a && console.log("PASS");
+    }
+    expect: {
+        var a = 0;
+        a || (++a).toString() && a && console.log("PASS");
+    }
+    expect_stdout: "PASS"
+}
