@@ -2144,3 +2144,63 @@ issue_5591: {
     ]
     node_version: ">=4"
 }
+
+issue_5656: {
+    options = {
+        collapse_vars: true,
+        merge_vars: true,
+    }
+    input: {
+        console.log(function(a) {
+            var b = a;
+            b++;
+            {
+                const a = b;
+            }
+        }());
+    }
+    expect: {
+        console.log(function(a) {
+            var b = a;
+            {
+                const a = ++b;
+            }
+        }());
+    }
+    expect_stdout: true
+}
+
+issue_5660: {
+    options = {
+        merge_vars: true,
+        side_effects: true,
+    }
+    input: {
+        function f() {
+            try {
+                a;
+                var b;
+                return b;
+            } catch (e) {
+                var a = "FAIL";
+                const b = null;
+                return a;
+            }
+        }
+        console.log(f());
+    }
+    expect: {
+        function f() {
+            try {
+                var b;
+                return b;
+            } catch (e) {
+                var a = "FAIL";
+                const b = null;
+                return a;
+            }
+        }
+        console.log(f());
+    }
+    expect_stdout: true
+}
