@@ -668,6 +668,8 @@ drop_fargs: {
 hoist_vars: {
     options = {
         hoist_vars: true,
+        join_vars: true,
+        unused: true,
     }
     input: {
         var a = "PASS";
@@ -675,8 +677,7 @@ hoist_vars: {
         console.log(a, b);
     }
     expect: {
-        var a = "PASS";
-        var [ b = 42 ] = [];
+        var a = "PASS", [ b = 42 ] = [];
         console.log(a, b);
     }
     expect_stdout: "PASS 42"
@@ -2504,7 +2505,7 @@ issue_5463: {
         var a, b, b;
         console.log("PASS") && (
             b = a = void 0,
-            b = [a = FAIL] = a && a
+            b = [a = FAIL] = a
         );
     }
     expect_stdout: "PASS"
@@ -2712,7 +2713,7 @@ issue_5533_2_drop_fargs: {
         try {
             (function() {
                 for (;;) {
-                    var [ [] = [] ] = [];
+                    var [ [ , ] = [] ] = [];
                     throw "PASS";
                 }
             })();
@@ -3035,10 +3036,36 @@ issue_5566_5: {
         (function(a, f = function() {
             return a;
         }) {
-            var b, a = "foo";
+            var a, b;
+            a = "foo";
             console.log(a, f());
         })("bar");
     }
     expect_stdout: "foo bar"
     node_version: ">=6"
 }
+
+issue_5651: {
+    options = {
+        ie: true,
+        unused: true,
+    }
+    input: {
+        console.log(function arguments(a = "FAIL") {
+            try {} catch (arguments) {
+                var arguments;
+            }
+            return arguments[0];
+        }());
+    }
+    expect: {
+        console.log(function arguments(a = "FAIL") {
+            try {} catch (arguments) {
+                var arguments;
+            }
+            return arguments[0];
+        }());
+    }
+    expect_stdout: true
+    node_version: ">=6"
+}
