@@ -1306,7 +1306,7 @@ keep_reference: {
     }
     expect: {
         var a = [ {}, 42 ];
-        var [ b ] = a;
+        var b = a[0];
         console.log(a[0] === b ? "PASS" : "FAIL");
     }
     expect_stdout: "PASS"
@@ -1652,6 +1652,8 @@ fn_name_unused: {
 hoist_vars: {
     options = {
         hoist_vars: true,
+        join_vars: true,
+        unused: true,
     }
     input: {
         var a = "PASS";
@@ -1659,8 +1661,7 @@ hoist_vars: {
         console.log(a, b);
     }
     expect: {
-        var a = "PASS";
-        var [ b ] = [ 42 ];
+        var a = "PASS", b = [ 42 ][0];
         console.log(a, b);
     }
     expect_stdout: "PASS 42"
@@ -1736,6 +1737,23 @@ singleton_side_effects: {
     node_version: ">=6"
 }
 
+mangle_properties: {
+    mangle = {
+        properties: {
+            domprops: true,
+        },
+    }
+    input: {
+        function f({ p: a }) {
+            return a;
+        }
+        console.log(f({ p: "PASS" }));
+    }
+    expect_exact: 'function f({n}){return n}console.log(f({n:"PASS"}));'
+    expect_stdout: "PASS"
+    node_version: ">=6"
+}
+
 issue_4280: {
     options = {
         evaluate: true,
@@ -3843,3 +3861,28 @@ issue_5573: {
     ]
     node_version: ">=6"
 }
+
+issue_5651: {
+    options = {
+        ie: true,
+        unused: true,
+    }
+    input: {
+        console.log(function arguments({}) {
+            try {} catch (arguments) {
+                var arguments;
+            }
+            return arguments[0];
+        }("PASS"));
+    }
+    expect: {
+        console.log(function arguments({}) {
+            try {} catch (arguments) {
+                var arguments;
+            }
+            return arguments[0];
+        }("PASS"));
+    }
+    expect_stdout: true
+    node_version: ">=6"
+}
