@@ -525,7 +525,7 @@ if_var_return_2: {
     }
 }
 
-if_var_retrn_3: {
+if_var_return_3: {
     options = {
         conditionals: true,
         if_return: true,
@@ -1834,6 +1834,63 @@ switch_return_5: {
     ]
 }
 
+merged_references_1: {
+    options = {
+        if_return: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        var a, b = "PASS";
+        console.log(function(c) {
+            if (c = b)
+                return a || c;
+            c = FAIL;
+            return a || c;
+        }());
+    }
+    expect: {
+        var a, b = "PASS";
+        console.log(function(c) {
+            if (c = b);
+            else
+                c = FAIL;
+            return a || c;
+        }());
+    }
+    expect_stdout: "PASS"
+}
+
+merged_references_2: {
+    options = {
+        if_return: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        A = "PASS";
+        var a;
+        console.log(function(b) {
+            if (a = b)
+                return console && a;
+            a = FAIL;
+            return console && a;
+        }(A));
+    }
+    expect: {
+        A = "PASS";
+        var a;
+        console.log(function(b) {
+            if (a = b);
+            else
+                a = FAIL;
+            return console && a;
+        }(A));
+    }
+    expect_stdout: "PASS"
+}
+
 issue_5583: {
     options = {
         conditionals: true,
@@ -2305,3 +2362,121 @@ issue_5597: {
     }
     expect_stdout: "PASS"
 }
+
+issue_5619_1: {
+    options = {
+        if_return: true,
+    }
+    input: {
+        console.log(function() {
+            if (console)
+                if (console)
+                    return "PASS";
+            var a = FAIL;
+            return "PASS";
+        }());
+    }
+    expect: {
+        console.log(function() {
+            if (console)
+                if (console)
+                    return "PASS";
+            var a = FAIL;
+            return "PASS";
+        }());
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5619_2: {
+    options = {
+        dead_code: true,
+        if_return: true,
+        loops: true,
+    }
+    input: {
+        console.log(function() {
+            if (console)
+                while (console)
+                    return "PASS";
+            var a = FAIL;
+            return "PASS";
+        }());
+    }
+    expect: {
+        console.log(function() {
+            if (console) {
+                if (console)
+                    return "PASS";
+            }
+            var a = FAIL;
+            return "PASS";
+        }());
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5649: {
+    options = {
+        if_return: true,
+    }
+    input: {
+        console.log(function() {
+            try {
+                throw new Error("FAIL");
+            } catch (e) {
+                return "PASS";
+            }
+            throw new Error("FAIL");
+        }());
+    }
+    expect: {
+        console.log(function() {
+            try {
+                throw new Error("FAIL");
+            } catch (e) {
+                return "PASS";
+            }
+            throw new Error("FAIL");
+        }());
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5688: {
+    options = {
+        conditionals: true,
+        if_return: true,
+    }
+    input: {
+        L: do {
+            switch (console) {
+              default:
+                if (console)
+                    break;
+                if (FAIL_1)
+                    ;
+                else
+                    break L;
+                break;
+              case 42:
+                FAIL_2;
+            }
+        } while (console.log("PASS"));
+    }
+    expect: {
+        L: do {
+            switch (console) {
+              default:
+                if (console)
+                    break;
+                if (FAIL_1)
+                    break;
+                break L;
+              case 42:
+                FAIL_2;
+            }
+        } while (console.log("PASS"));
+    }
+    expect_stdout: "PASS"
+}
