@@ -169,6 +169,158 @@ conditional_branch: {
     expect_stdout: "PASS"
 }
 
+conditional_chain_1: {
+    options = {
+        merge_vars: true,
+    }
+    input: {
+        function f(a, b) {
+            var c, d;
+            if (a && (c = a))
+                console.log(c);
+            else
+                b || (d = b) ? console.log("foo") : console.log(d);
+        }
+        f("", null);
+        f("", true);
+        f(42, null);
+        f(42, true);
+    }
+    expect: {
+        function f(a, b) {
+            var a, a;
+            if (a && (a = a))
+                console.log(a);
+            else
+                b || (a = b) ? console.log("foo") : console.log(a);
+        }
+        f("", null);
+        f("", true);
+        f(42, null);
+        f(42, true);
+    }
+    expect_stdout: [
+        "null",
+        "foo",
+        "42",
+        "42",
+    ]
+}
+
+conditional_chain_2: {
+    options = {
+        merge_vars: true,
+    }
+    input: {
+        function f(a, b) {
+            var c, d;
+            if (a && (c = a))
+                console.log(c);
+            else
+                b || (d = b) ? console.log(c) : console.log(d);
+        }
+        f("", null);
+        f("", true);
+        f(42, null);
+        f(42, true);
+    }
+    expect: {
+        function f(a, b) {
+            var c, a;
+            if (a && (c = a))
+                console.log(c);
+            else
+                b || (a = b) ? console.log(c) : console.log(a);
+        }
+        f("", null);
+        f("", true);
+        f(42, null);
+        f(42, true);
+    }
+    expect_stdout: [
+        "null",
+        "undefined",
+        "42",
+        "42",
+    ]
+}
+
+conditional_chain_3: {
+    options = {
+        merge_vars: true,
+    }
+    input: {
+        function f(a, b) {
+            var c, d;
+            if (a && (c = a) || b || (d = b))
+                console.log(c);
+            else
+                console.log(d);
+        }
+        f("", null);
+        f("", true);
+        f(42, null);
+        f(42, true);
+    }
+    expect: {
+        function f(a, b) {
+            var c, a;
+            if (a && (c = a) || b || (a = b))
+                console.log(c);
+            else
+                console.log(a);
+        }
+        f("", null);
+        f("", true);
+        f(42, null);
+        f(42, true);
+    }
+    expect_stdout: [
+        "null",
+        "undefined",
+        "42",
+        "42",
+    ]
+}
+
+conditional_chain_4: {
+    options = {
+        merge_vars: true,
+    }
+    input: {
+        function f(a, b) {
+            var c, d;
+            if (a && b ? c = a : d = b)
+                console.log(c);
+            else
+                console.log(d);
+        }
+        f("", null);
+        f("", true);
+        f(42, null);
+        f(42, true);
+    }
+    expect: {
+        function f(a, b) {
+            var c, d;
+            if (a && b ? c = a : d = b)
+                console.log(c);
+            else
+                console.log(d);
+        }
+        f("", null);
+        f("", true);
+        f(42, null);
+        f(42, true);
+    }
+    expect_stdout: [
+        "null",
+        "undefined",
+        "null",
+        "42",
+    ]
+}
+
 if_branch: {
     options = {
         merge_vars: true,
@@ -253,6 +405,7 @@ read_before_assign_1: {
         inline: true,
         merge_vars: true,
         sequences: true,
+        side_effects: true,
         toplevel: true,
     }
     input: {
@@ -3549,3 +3702,190 @@ issue_5182: {
     ]
     node_version: ">=4"
 }
+
+issue_5420: {
+    options = {
+        merge_vars: true,
+        toplevel: true,
+    }
+    input: {
+        do {
+            var a = "FAIL 1";
+            a && a.p;
+            a = "FAIL 2";
+            try {
+                continue;
+            } catch (e) {}
+            var b = "FAIL 3";
+        } while (console.log(b || "PASS"));
+    }
+    expect: {
+        do {
+            var a = "FAIL 1";
+            a && a.p;
+            a = "FAIL 2";
+            try {
+                continue;
+            } catch (e) {}
+            var b = "FAIL 3";
+        } while (console.log(b || "PASS"));
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5451: {
+    options = {
+        merge_vars: true,
+        toplevel: true,
+    }
+    input: {
+        A = 1;
+        var a = 1, b;
+        console.log(function f() {
+            return a-- && f(b = A, b);
+        }());
+    }
+    expect: {
+        A = 1;
+        var a = 1, b;
+        console.log(function f() {
+            return a-- && f(b = A, b);
+        }());
+    }
+    expect_stdout: "0"
+}
+
+issue_5471_1: {
+    options = {
+        conditionals: true,
+        inline: true,
+        merge_vars: true,
+        reduce_vars: true,
+        sequences: true,
+        side_effects: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var a = "FAIL 1";
+        function f(b, c) {
+            function g() {
+                if (console)
+                    return 42;
+                else
+                    c = "FAIL 2";
+            }
+            var d = g();
+            console.log(c || "PASS");
+            var e = function h() {
+                while (b && e);
+            }();
+        }
+        f(a++) && a;
+    }
+    expect: {
+        var a = "FAIL 1";
+        var b, c, e;
+        b = +a,
+        function() {
+            if (console)
+                return;
+            c = "FAIL 2";
+        }(),
+        console.log(c || "PASS"),
+        e = function() {
+            while (b && e);
+        }();
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5471_2: {
+    options = {
+        conditionals: true,
+        evaluate: true,
+        inline: true,
+        merge_vars: true,
+        reduce_vars: true,
+        sequences: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var a = "FAIL 1";
+        function f(b, c) {
+            function g() {
+                if (console)
+                    return 42;
+                else
+                    c = "FAIL 2";
+            }
+            var d = g();
+            console.log(c || "PASS");
+            var e = function h() {
+                while (b && e);
+            }();
+        }
+        f(a++) && a;
+    }
+    expect: {
+        var a = "FAIL 1";
+        var b, c, e;
+        b = +a,
+        function() {
+            if (console)
+                return;
+            c = "FAIL 2";
+        }(),
+        console.log(c || "PASS"),
+        e = function() {
+            while (b && e);
+        }(),
+        void 0;
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5714: {
+    options = {
+        inline: true,
+        join_vars: true,
+        loops: true,
+        merge_vars: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        console.log(function() {
+            var i = 1;
+            while (i--) {
+                var a = function f(b) {
+                    console.log(b);
+                    var c = function(d) {
+                        console.log(typeof d);
+                    }(console);
+                }();
+                var e = 42;
+            }
+            return e;
+        }());
+    }
+    expect: {
+        "use strict";
+        console.log(function() {
+            for (var i = 1; i--;) {
+                var b = void 0;
+                console.log(b);
+                b = console,
+                console.log(typeof b);
+                var e = 42;
+            }
+            return e;
+        }());
+    }
+    expect_stdout: [
+        "undefined",
+        "object",
+        "42",
+    ]
+}
