@@ -133,6 +133,7 @@ evaluate_string_length: {
 mangle_properties_1: {
     mangle = {
         properties: {
+            domprops: true,
             keep_quoted: false,
         },
     }
@@ -147,17 +148,18 @@ mangle_properties_1: {
         a["a"] = "bar";
         a.b = "red";
         x = {o: 10};
-        a.r(x.o, a.a);
-        a['r']({b: "blue", a: "baz"});
+        a.run(x.o, a.a);
+        a['run']({b: "blue", a: "baz"});
     }
 }
 
 mangle_properties_2: {
     mangle = {
         properties: {
+            domprops: true,
             reserved: [
                 "value",
-            ]
+            ],
         },
     }
     input: {
@@ -199,6 +201,24 @@ mangle_properties_2: {
     ]
 }
 
+mangle_properties_3: {
+    mangle = {
+        properties: true,
+    }
+    input: {
+        console.log({
+            [(console, "foo")]: "PASS",
+        }.foo);
+    }
+    expect: {
+        console.log({
+            [(console, "o")]: "PASS",
+        }.o);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
 mangle_unquoted_properties: {
     options = {
         evaluate: true,
@@ -207,6 +227,7 @@ mangle_unquoted_properties: {
     mangle = {
         properties: {
             builtins: true,
+            domprops: true,
             keep_quoted: true,
         },
     }
@@ -308,6 +329,7 @@ mangle_debug_suffix_keep_quoted: {
         properties: {
             builtins: true,
             debug: "XYZ",
+            domprops: true,
             keep_quoted: true,
             reserved: [],
         },
@@ -353,6 +375,68 @@ mangle_debug_suffix_keep_quoted: {
     }
 }
 
+keep_substituted_property: {
+    options = {
+        evaluate: true,
+        properties: true,
+        reduce_vars: true,
+    }
+    mangle = {
+        properties: {
+            keep_quoted: true,
+        },
+    }
+    input: {
+        var o = { p: [] };
+        function f(b) {
+            return o[b];
+        }
+        function g() {
+            var a = "p";
+            return o[a] === f(a);
+        }
+        console.log(g() ? "PASS" : "FAIL");
+    }
+    expect: {
+        var o = { p: [] };
+        function f(n) {
+            return o[n];
+        }
+        function g() {
+            var n = "p";
+            return o.p === f(n);
+        }
+        console.log(g() ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+}
+
+keep_substituted_property_quotes: {
+    options = {
+        evaluate: true,
+        properties: true,
+        reduce_vars: true,
+    }
+    beautify = {
+        keep_quoted_props: true,
+    }
+    input: {
+        function f(o) {
+            var a = "p";
+            return o[a];
+        }
+        console.log(f({ p: "PASS" }));
+    }
+    expect: {
+        function f(o) {
+            var a = "p";
+            return o["p"];
+        }
+        console.log(f({ p: "PASS" }));
+    }
+    expect_stdout: "PASS"
+}
+
 first_256_chars_as_properties: {
     beautify = {
         ascii_only: true,
@@ -899,12 +983,15 @@ issue_2256: {
         },
     }
     input: {
-        ({ "keep": 1 });
-        g.keep = g.change;
+        ({ "keep": 42 });
+        global.keep = global.change = "PASS";
+        console.log(keep);
     }
     expect: {
-        g.keep = g.g;
+        global.keep = global.l = "PASS";
+        console.log(keep);
     }
+    expect_stdout: "PASS"
 }
 
 lhs_prop_1: {
@@ -1580,3 +1667,163 @@ issue_5177: {
     expect_stdout: "PASS"
     node_version: ">=4"
 }
+
+issue_5682_in_1: {
+    mangle = {
+        properties: true,
+    }
+    input: {
+        function f(a) {
+            return "foo" in a;
+        }
+        var o = {};
+        var p = "foo";
+        o[p] = 42;
+        console.log(f(o) ? "PASS" : "FAIL");
+    }
+    expect: {
+        function f(o) {
+            return "foo" in o;
+        }
+        var o = {};
+        var p = "foo";
+        o[p] = 42;
+        console.log(f(o) ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5682_in_2: {
+    mangle = {
+        properties: true,
+    }
+    input: {
+        function f(a) {
+            return "foo" in a;
+        }
+        var o = { foo: 42 };
+        console.log(f(o) ? "PASS" : "FAIL");
+    }
+    expect: {
+        function f(o) {
+            return "o" in o;
+        }
+        var o = { o: 42 };
+        console.log(f(o) ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5682_dot_1: {
+    mangle = {
+        properties: true,
+    }
+    input: {
+        function f(a) {
+            return a.foo;
+        }
+        var o = {};
+        var p = "foo";
+        o[p] = "PASS";
+        console.log(f(o));
+    }
+    expect: {
+        function f(o) {
+            return o.foo;
+        }
+        var o = {};
+        var p = "foo";
+        o[p] = "PASS";
+        console.log(f(o));
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5682_dot_2: {
+    mangle = {
+        properties: true,
+    }
+    input: {
+        function f(a) {
+            return a.foo;
+        }
+        var o = { foo: "PASS" };
+        console.log(f(o));
+    }
+    expect: {
+        function f(o) {
+            return o.o;
+        }
+        var o = { o: "PASS" };
+        console.log(f(o));
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5682_dot_2_computed: {
+    mangle = {
+        properties: true,
+    }
+    input: {
+        function f(a) {
+            return a.foo;
+        }
+        var o = { ["foo"]: "PASS" };
+        console.log(f(o));
+    }
+    expect: {
+        function f(o) {
+            return o.o;
+        }
+        var o = { ["o"]: "PASS" };
+        console.log(f(o));
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
+issue_5682_sub_1: {
+    mangle = {
+        properties: true,
+    }
+    input: {
+        function f(a) {
+            return a["foo"];
+        }
+        var o = {};
+        var p = "foo";
+        o[p] = "PASS";
+        console.log(f(o));
+    }
+    expect: {
+        function f(o) {
+            return o["foo"];
+        }
+        var o = {};
+        var p = "foo";
+        o[p] = "PASS";
+        console.log(f(o));
+    }
+    expect_stdout: "PASS"
+}
+
+issue_5682_sub_2: {
+    mangle = {
+        properties: true,
+    }
+    input: {
+        function f(a) {
+            return a["foo"];
+        }
+        var o = { foo: "PASS" };
+        console.log(f(o));
+    }
+    expect: {
+        function f(o) {
+            return o["o"];
+        }
+        var o = { o: "PASS" };
+        console.log(f(o));
+    }
+    expect_stdout: "PASS"
+}
