@@ -127,7 +127,7 @@ if_return: {
                 if (w) {
                     if (y) return;
                 } else if (z) return;
-                return x != y && (x && w(), y && z()), !0;
+                return x != y && (x && w(), y) && z(), !0;
             }
         }
     }
