@@ -194,6 +194,43 @@ scope_adjustment_let: {
     node_version: ">=4"
 }
 
+escaped_const: {
+    options = {
+        reduce_vars: true,
+        toplevel: true,
+        varify: true,
+    }
+    input: {
+        const log = console.log;
+        log("PASS");
+    }
+    expect: {
+        var log = console.log;
+        log("PASS");
+    }
+    expect_stdout: "PASS"
+}
+
+escaped_let: {
+    options = {
+        reduce_vars: true,
+        toplevel: true,
+        varify: true,
+    }
+    input: {
+        "use strict";
+        let log = console.log;
+        log("PASS");
+    }
+    expect: {
+        "use strict";
+        var log = console.log;
+        log("PASS");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
 issue_4191_const: {
     options = {
         functions: true,
@@ -645,3 +682,165 @@ issue_5516: {
     expect_stdout: "function"
     node_version: ">=4"
 }
+
+issue_5697_1: {
+    options = {
+        if_return: true,
+        inline: true,
+        reduce_vars: true,
+        unused: true,
+        varify: true,
+    }
+    input: {
+        console.log(function() {
+            f();
+            return typeof a;
+            function f() {
+                (function() {
+                    for (var k in { foo: 42 }) {
+                        const a = k;
+                        console.log(a);
+                    }
+                })();
+            }
+        }());
+    }
+    expect: {
+        console.log(function() {
+            (function() {
+                for (var k in { foo: 42 }) {
+                    var a = k;
+                    console.log(a);
+                }
+            })();
+            return typeof a;
+        }());
+    }
+    expect_stdout: [
+        "foo",
+        "undefined",
+    ]
+}
+
+issue_5697_2: {
+    options = {
+        if_return: true,
+        inline: true,
+        reduce_vars: true,
+        unused: true,
+        varify: true,
+    }
+    input: {
+        "use strict";
+        console.log(function() {
+            f();
+            return typeof a;
+            function f() {
+                (function() {
+                    for (var k in { foo: 42 }) {
+                        let a = k;
+                        console.log(a);
+                    }
+                })();
+            }
+        }());
+    }
+    expect: {
+        "use strict";
+        console.log(function() {
+            (function() {
+                for (var k in { foo: 42 }) {
+                    var a = k;
+                    console.log(a);
+                }
+            })();
+            return typeof a;
+        }());
+    }
+    expect_stdout: [
+        "foo",
+        "undefined",
+    ]
+    node_version: ">=4"
+}
+
+issue_5697_3: {
+    options = {
+        inline: true,
+        reduce_vars: true,
+        side_effects: true,
+        unused: true,
+        varify: true,
+    }
+    input: {
+        console.log(function() {
+            f();
+            return typeof a;
+            function f() {
+                (function() {
+                    for (var k in { foo: 42 }) {
+                        const a = k;
+                        console.log(a);
+                    }
+                })();
+            }
+        }());
+    }
+    expect: {
+        console.log(function() {
+            (function() {
+                for (var k in { foo: 42 }) {
+                    var a = k;
+                    console.log(a);
+                }
+            })();
+            return typeof a;
+        }());
+    }
+    expect_stdout: [
+        "foo",
+        "undefined",
+    ]
+}
+
+issue_5697_4: {
+    options = {
+        inline: true,
+        reduce_vars: true,
+        side_effects: true,
+        unused: true,
+        varify: true,
+    }
+    input: {
+        "use strict";
+        console.log(function() {
+            f();
+            return typeof a;
+            function f() {
+                (function() {
+                    for (var k in { foo: 42 }) {
+                        let a = k;
+                        console.log(a);
+                    }
+                })();
+            }
+        }());
+    }
+    expect: {
+        "use strict";
+        console.log(function() {
+            (function() {
+                for (var k in { foo: 42 }) {
+                    var a = k;
+                    console.log(a);
+                }
+            })();
+            return typeof a;
+        }());
+    }
+    expect_stdout: [
+        "foo",
+        "undefined",
+    ]
+    node_version: ">=4"
+}
