@@ -1735,3 +1735,344 @@ issue_5576: {
     ]
     node_version: ">=10"
 }
+
+issue_5663: {
+    options = {
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var [ , a ] = function*() {
+            console.log("foo");
+            yield console.log("bar");
+            console.log("baz");
+            yield console.log("moo");
+            console.log("moz");
+            yield FAIL;
+        }();
+    }
+    expect: {
+        var [ , , ] = function*() {
+            console.log("foo");
+            yield console.log("bar");
+            console.log("baz");
+            yield console.log("moo");
+            console.log("moz");
+            yield FAIL;
+        }();
+    }
+    expect_stdout: [
+        "foo",
+        "bar",
+        "baz",
+        "moo",
+    ]
+    node_version: ">=6"
+}
+
+issue_5679_1: {
+    options = {
+        conditionals: true,
+    }
+    input: {
+        var a = "FAIL";
+        async function* f(b) {
+            try {
+                if (b)
+                    return;
+                else
+                    return;
+            } finally {
+                a = "PASS";
+            }
+        }
+        f().next();
+        console.log(a);
+    }
+    expect: {
+        var a = "FAIL";
+        async function* f(b) {
+            try {
+                b;
+                return;
+            } finally {
+                a = "PASS";
+            }
+        }
+        f().next();
+        console.log(a);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=10"
+}
+
+issue_5679_2: {
+    options = {
+        conditionals: true,
+    }
+    input: {
+        var a = "FAIL";
+        async function* f(b) {
+            try {
+                if (b)
+                    return undefined;
+                else
+                    return;
+            } finally {
+                a = "PASS";
+            }
+        }
+        f().next();
+        console.log(a);
+    }
+    expect: {
+        var a = "FAIL";
+        async function* f(b) {
+            try {
+                if (b)
+                    return void 0;
+                return;
+            } finally {
+                a = "PASS";
+            }
+        }
+        f().next();
+        console.log(a);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=10"
+}
+
+issue_5679_3: {
+    options = {
+        conditionals: true,
+    }
+    input: {
+        var a = "FAIL";
+        async function* f(b) {
+            try {
+                if (b)
+                    return;
+                else
+                    return undefined;
+            } finally {
+                a = "PASS";
+            }
+        }
+        f(42).next();
+        console.log(a);
+    }
+    expect: {
+        var a = "FAIL";
+        async function* f(b) {
+            try {
+                if (b)
+                    return;
+                return void 0;
+            } finally {
+                a = "PASS";
+            }
+        }
+        f(42).next();
+        console.log(a);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=10"
+}
+
+issue_5679_4: {
+    options = {
+        conditionals: true,
+    }
+    input: {
+        var a = "PASS";
+        async function* f(b) {
+            try {
+                if (b)
+                    return undefined;
+                else
+                    return undefined;
+            } finally {
+                a = "FAIL";
+            }
+        }
+        f(null).next();
+        console.log(a);
+    }
+    expect: {
+        var a = "PASS";
+        async function* f(b) {
+            try {
+                return b, void 0;
+            } finally {
+                a = "FAIL";
+            }
+        }
+        f(null).next();
+        console.log(a);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=10"
+}
+
+issue_5679_5: {
+    options = {
+        conditionals: true,
+        if_return: true,
+    }
+    input: {
+        var a = "FAIL";
+        async function* f(b) {
+            try {
+                if (b)
+                    return console;
+                else
+                    return;
+            } finally {
+                a = "PASS";
+            }
+        }
+        f().next();
+        console.log(a);
+    }
+    expect: {
+        var a = "FAIL";
+        async function* f(b) {
+            try {
+                if (b)
+                    return console;
+                return;
+            } finally {
+                a = "PASS";
+            }
+        }
+        f().next();
+        console.log(a);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=10"
+}
+
+issue_5679_6: {
+    options = {
+        conditionals: true,
+        if_return: true,
+    }
+    input: {
+        var a = "PASS";
+        async function* f(b) {
+            try {
+                if (b)
+                    return;
+                else
+                    return console;
+            } finally {
+                a = "FAIL";
+            }
+        }
+        f().next();
+        console.log(a);
+    }
+    expect: {
+        var a = "PASS";
+        async function* f(b) {
+            try {
+                if (!b)
+                    return console;
+            } finally {
+                a = "FAIL";
+            }
+        }
+        f().next();
+        console.log(a);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=10"
+}
+
+issue_5684: {
+    options = {
+        conditionals: true,
+        if_return: true,
+    }
+    input: {
+        (async function*() {
+            switch (42) {
+              default:
+                if (console.log("PASS"))
+                    return;
+                return null;
+              case false:
+            }
+        })().next();
+    }
+    expect: {
+        (async function*() {
+            switch (42) {
+              default:
+                return console.log("PASS") ? void 0 : null;
+              case false:
+            }
+        })().next();
+    }
+    expect_stdout: "PASS"
+    node_version: ">=10"
+}
+
+issue_5707: {
+    options = {
+        hoist_props: true,
+        reduce_vars: true,
+        side_effects: true,
+        toplevel: true,
+        unused: true,
+        yields: true,
+    }
+    input: {
+        var a, b;
+        function* f(c = (b = 42, console.log("PASS"))) {}
+        b = f();
+    }
+    expect: {
+        console.log("PASS");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=6"
+}
+
+issue_5710: {
+    options = {
+        conditionals: true,
+        if_return: true,
+    }
+    input: {
+        (async function*() {
+            try {
+                switch (42) {
+                  case 42:
+                    {
+                        if (console.log("PASS"))
+                            return;
+                        return null;
+                    }
+                    break;
+                }
+            } finally {}
+        })().next();
+    }
+    expect: {
+        (async function*() {
+            try {
+                switch (42) {
+                  case 42:
+                    if (console.log("PASS"))
+                        return;
+                    return null;
+                    break;
+                }
+            } finally {}
+        })().next();
+    }
+    expect_stdout: "PASS"
+    node_version: ">=10"
+}
