@@ -14,6 +14,13 @@ minify_in_situ() {
     uglify-js $ARGS
 }
 
+npm_install() {
+    PKG="$1"
+    while !(npm install $PKG); do
+        while !(npm cache clean --force); do echo "'npm cache clean' failed - retrying..."; done
+    done
+}
+
 rm -rf tmp/buble \
 && git clone https://github.com/bublejs/buble.git tmp/buble \
 && cd tmp/buble \
@@ -38,7 +45,7 @@ EOF
 ERR=$?; if [ "$ERR" != "0" ]; then echo "Error: $ERR"; exit $ERR; fi
 minify_in_situ "src" \
 && rm -rf node_modules \
-&& npm ci \
+&& npm_install \
 && rm -rf dist \
 && npm run build \
 && minify_in_situ "dist" \
